# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._data_result_value import DataResultValue
from ._data_session_stat_client_stats_value import DataSessionStatClientStatsValue
from ._data_session_stat_db_stats_value import DataSessionStatDbStatsValue
from ._data_value import DataValue
from ._add_hdminstance_request import AddHDMInstanceRequest
from ._add_hdminstance_response_body import AddHDMInstanceResponseBody
from ._add_hdminstance_response import AddHDMInstanceResponse
from ._create_cache_analysis_job_request import CreateCacheAnalysisJobRequest
from ._create_cache_analysis_job_response_body import CreateCacheAnalysisJobResponseBody
from ._create_cache_analysis_job_response import CreateCacheAnalysisJobResponse
from ._create_cloud_bench_tasks_request import CreateCloudBenchTasksRequest
from ._create_cloud_bench_tasks_response_body import CreateCloudBenchTasksResponseBody
from ._create_cloud_bench_tasks_response import CreateCloudBenchTasksResponse
from ._create_diagnostic_report_request import CreateDiagnosticReportRequest
from ._create_diagnostic_report_response_body import CreateDiagnosticReportResponseBody
from ._create_diagnostic_report_response import CreateDiagnosticReportResponse
from ._create_kill_instance_session_task_request import CreateKillInstanceSessionTaskRequest
from ._create_kill_instance_session_task_response_body import CreateKillInstanceSessionTaskResponseBody
from ._create_kill_instance_session_task_response import CreateKillInstanceSessionTaskResponse
from ._create_kill_instance_session_task_with_maintain_user_request import CreateKillInstanceSessionTaskWithMaintainUserRequest
from ._create_kill_instance_session_task_with_maintain_user_response_body import CreateKillInstanceSessionTaskWithMaintainUserResponseBody
from ._create_kill_instance_session_task_with_maintain_user_response import CreateKillInstanceSessionTaskWithMaintainUserResponse
from ._create_latest_dead_lock_analysis_request import CreateLatestDeadLockAnalysisRequest
from ._create_latest_dead_lock_analysis_response_body import CreateLatestDeadLockAnalysisResponseBody
from ._create_latest_dead_lock_analysis_response import CreateLatestDeadLockAnalysisResponse
from ._create_query_optimize_tag_request import CreateQueryOptimizeTagRequest
from ._create_query_optimize_tag_response_body import CreateQueryOptimizeTagResponseBody
from ._create_query_optimize_tag_response import CreateQueryOptimizeTagResponse
from ._create_request_diagnosis_request import CreateRequestDiagnosisRequest
from ._create_request_diagnosis_response_body import CreateRequestDiagnosisResponseBody
from ._create_request_diagnosis_response import CreateRequestDiagnosisResponse
from ._create_security_ipgroup_request import CreateSecurityIPGroupRequest
from ._create_security_ipgroup_response_body import CreateSecurityIPGroupResponseBody
from ._create_security_ipgroup_response import CreateSecurityIPGroupResponse
from ._create_sql_log_task_request import CreateSqlLogTaskRequest
from ._create_sql_log_task_response_body import CreateSqlLogTaskResponseBody
from ._create_sql_log_task_response import CreateSqlLogTaskResponse
from ._create_storage_analysis_task_request import CreateStorageAnalysisTaskRequest
from ._create_storage_analysis_task_response_body import CreateStorageAnalysisTaskResponseBody
from ._create_storage_analysis_task_response import CreateStorageAnalysisTaskResponse
from ._delete_cloud_bench_task_request import DeleteCloudBenchTaskRequest
from ._delete_cloud_bench_task_response_body import DeleteCloudBenchTaskResponseBody
from ._delete_cloud_bench_task_response import DeleteCloudBenchTaskResponse
from ._delete_security_ipgroup_request import DeleteSecurityIPGroupRequest
from ._delete_security_ipgroup_response_body import DeleteSecurityIPGroupResponseBody
from ._delete_security_ipgroup_response import DeleteSecurityIPGroupResponse
from ._delete_stop_gateway_request import DeleteStopGatewayRequest
from ._delete_stop_gateway_response_body import DeleteStopGatewayResponseBody
from ._delete_stop_gateway_response import DeleteStopGatewayResponse
from ._describe_auto_scaling_config_request import DescribeAutoScalingConfigRequest
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBody
from ._describe_auto_scaling_config_response import DescribeAutoScalingConfigResponse
from ._describe_auto_scaling_history_request import DescribeAutoScalingHistoryRequest
from ._describe_auto_scaling_history_response_body import DescribeAutoScalingHistoryResponseBody
from ._describe_auto_scaling_history_response import DescribeAutoScalingHistoryResponse
from ._describe_cache_analysis_job_request import DescribeCacheAnalysisJobRequest
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBody
from ._describe_cache_analysis_job_response import DescribeCacheAnalysisJobResponse
from ._describe_cache_analysis_jobs_request import DescribeCacheAnalysisJobsRequest
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBody
from ._describe_cache_analysis_jobs_response import DescribeCacheAnalysisJobsResponse
from ._describe_cloud_bench_tasks_request import DescribeCloudBenchTasksRequest
from ._describe_cloud_bench_tasks_response_body import DescribeCloudBenchTasksResponseBody
from ._describe_cloud_bench_tasks_response import DescribeCloudBenchTasksResponse
from ._describe_cloudbench_task_request import DescribeCloudbenchTaskRequest
from ._describe_cloudbench_task_response_body import DescribeCloudbenchTaskResponseBody
from ._describe_cloudbench_task_response import DescribeCloudbenchTaskResponse
from ._describe_cloudbench_task_config_request import DescribeCloudbenchTaskConfigRequest
from ._describe_cloudbench_task_config_response_body import DescribeCloudbenchTaskConfigResponseBody
from ._describe_cloudbench_task_config_response import DescribeCloudbenchTaskConfigResponse
from ._describe_diagnostic_report_list_request import DescribeDiagnosticReportListRequest
from ._describe_diagnostic_report_list_response_body import DescribeDiagnosticReportListResponseBody
from ._describe_diagnostic_report_list_response import DescribeDiagnosticReportListResponse
from ._describe_error_log_records_request import DescribeErrorLogRecordsRequest
from ._describe_error_log_records_response_body import DescribeErrorLogRecordsResponseBody
from ._describe_error_log_records_response import DescribeErrorLogRecordsResponse
from ._describe_hot_big_keys_request import DescribeHotBigKeysRequest
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBody
from ._describe_hot_big_keys_response import DescribeHotBigKeysResponse
from ._describe_hot_keys_request import DescribeHotKeysRequest
from ._describe_hot_keys_response_body import DescribeHotKeysResponseBody
from ._describe_hot_keys_response import DescribeHotKeysResponse
from ._describe_instance_das_pro_request import DescribeInstanceDasProRequest
from ._describe_instance_das_pro_response_body import DescribeInstanceDasProResponseBody
from ._describe_instance_das_pro_response import DescribeInstanceDasProResponse
from ._describe_query_explain_request import DescribeQueryExplainRequest
from ._describe_query_explain_response_body import DescribeQueryExplainResponseBody
from ._describe_query_explain_response import DescribeQueryExplainResponse
from ._describe_security_ipgroup_request import DescribeSecurityIPGroupRequest
from ._describe_security_ipgroup_response_body import DescribeSecurityIPGroupResponseBody
from ._describe_security_ipgroup_response import DescribeSecurityIPGroupResponse
from ._describe_security_ipgroup_relation_request import DescribeSecurityIPGroupRelationRequest
from ._describe_security_ipgroup_relation_response_body import DescribeSecurityIPGroupRelationResponseBody
from ._describe_security_ipgroup_relation_response import DescribeSecurityIPGroupRelationResponse
from ._describe_slow_log_histogram_async_request import DescribeSlowLogHistogramAsyncRequest
from ._describe_slow_log_histogram_async_response_body import DescribeSlowLogHistogramAsyncResponseBody
from ._describe_slow_log_histogram_async_response import DescribeSlowLogHistogramAsyncResponse
from ._describe_slow_log_records_request import DescribeSlowLogRecordsRequest
from ._describe_slow_log_records_response_body import DescribeSlowLogRecordsResponseBody
from ._describe_slow_log_records_response import DescribeSlowLogRecordsResponse
from ._describe_slow_log_statistic_request import DescribeSlowLogStatisticRequest
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBody
from ._describe_slow_log_statistic_response import DescribeSlowLogStatisticResponse
from ._describe_sql_log_config_request import DescribeSqlLogConfigRequest
from ._describe_sql_log_config_response_body import DescribeSqlLogConfigResponseBody
from ._describe_sql_log_config_response import DescribeSqlLogConfigResponse
from ._describe_sql_log_records_request import DescribeSqlLogRecordsRequest
from ._describe_sql_log_records_response_body import DescribeSqlLogRecordsResponseBody
from ._describe_sql_log_records_response import DescribeSqlLogRecordsResponse
from ._describe_sql_log_statistic_request import DescribeSqlLogStatisticRequest
from ._describe_sql_log_statistic_response_body import DescribeSqlLogStatisticResponseBody
from ._describe_sql_log_statistic_response import DescribeSqlLogStatisticResponse
from ._describe_sql_log_task_request import DescribeSqlLogTaskRequest
from ._describe_sql_log_task_response_body import DescribeSqlLogTaskResponseBody
from ._describe_sql_log_task_response import DescribeSqlLogTaskResponse
from ._describe_sql_log_tasks_request import DescribeSqlLogTasksRequest
from ._describe_sql_log_tasks_response_body import DescribeSqlLogTasksResponseBody
from ._describe_sql_log_tasks_response import DescribeSqlLogTasksResponse
from ._describe_top_big_keys_request import DescribeTopBigKeysRequest
from ._describe_top_big_keys_response_body import DescribeTopBigKeysResponseBody
from ._describe_top_big_keys_response import DescribeTopBigKeysResponse
from ._describe_top_hot_keys_request import DescribeTopHotKeysRequest
from ._describe_top_hot_keys_response_body import DescribeTopHotKeysResponseBody
from ._describe_top_hot_keys_response import DescribeTopHotKeysResponse
from ._disable_all_sql_concurrency_control_rules_request import DisableAllSqlConcurrencyControlRulesRequest
from ._disable_all_sql_concurrency_control_rules_response_body import DisableAllSqlConcurrencyControlRulesResponseBody
from ._disable_all_sql_concurrency_control_rules_response import DisableAllSqlConcurrencyControlRulesResponse
from ._disable_auto_resource_optimize_rules_request import DisableAutoResourceOptimizeRulesRequest
from ._disable_auto_resource_optimize_rules_response_body import DisableAutoResourceOptimizeRulesResponseBody
from ._disable_auto_resource_optimize_rules_response import DisableAutoResourceOptimizeRulesResponse
from ._disable_auto_throttle_rules_request import DisableAutoThrottleRulesRequest
from ._disable_auto_throttle_rules_response_body import DisableAutoThrottleRulesResponseBody
from ._disable_auto_throttle_rules_response import DisableAutoThrottleRulesResponse
from ._disable_das_pro_request import DisableDasProRequest
from ._disable_das_pro_response_body import DisableDasProResponseBody
from ._disable_das_pro_response import DisableDasProResponse
from ._disable_instance_das_config_request import DisableInstanceDasConfigRequest
from ._disable_instance_das_config_response_body import DisableInstanceDasConfigResponseBody
from ._disable_instance_das_config_response import DisableInstanceDasConfigResponse
from ._disable_sql_concurrency_control_request import DisableSqlConcurrencyControlRequest
from ._disable_sql_concurrency_control_response_body import DisableSqlConcurrencyControlResponseBody
from ._disable_sql_concurrency_control_response import DisableSqlConcurrencyControlResponse
from ._enable_das_pro_request import EnableDasProRequest
from ._enable_das_pro_response_body import EnableDasProResponseBody
from ._enable_das_pro_response import EnableDasProResponse
from ._enable_sql_concurrency_control_request import EnableSqlConcurrencyControlRequest
from ._enable_sql_concurrency_control_response_body import EnableSqlConcurrencyControlResponseBody
from ._enable_sql_concurrency_control_response import EnableSqlConcurrencyControlResponse
from ._get_async_error_request_list_by_code_request import GetAsyncErrorRequestListByCodeRequest
from ._get_async_error_request_list_by_code_response_body import GetAsyncErrorRequestListByCodeResponseBody
from ._get_async_error_request_list_by_code_response import GetAsyncErrorRequestListByCodeResponse
from ._get_async_error_request_stat_by_code_request import GetAsyncErrorRequestStatByCodeRequest
from ._get_async_error_request_stat_by_code_response_body import GetAsyncErrorRequestStatByCodeResponseBody
from ._get_async_error_request_stat_by_code_response import GetAsyncErrorRequestStatByCodeResponse
from ._get_async_error_request_stat_result_request import GetAsyncErrorRequestStatResultRequest
from ._get_async_error_request_stat_result_response_body import GetAsyncErrorRequestStatResultResponseBody
from ._get_async_error_request_stat_result_response import GetAsyncErrorRequestStatResultResponse
from ._get_auto_increment_usage_statistic_request import GetAutoIncrementUsageStatisticRequest
from ._get_auto_increment_usage_statistic_response_body import GetAutoIncrementUsageStatisticResponseBody
from ._get_auto_increment_usage_statistic_response import GetAutoIncrementUsageStatisticResponse
from ._get_auto_resource_optimize_rules_request import GetAutoResourceOptimizeRulesRequest
from ._get_auto_resource_optimize_rules_response_body import GetAutoResourceOptimizeRulesResponseBody
from ._get_auto_resource_optimize_rules_response import GetAutoResourceOptimizeRulesResponse
from ._get_auto_throttle_rules_request import GetAutoThrottleRulesRequest
from ._get_auto_throttle_rules_response_body import GetAutoThrottleRulesResponseBody
from ._get_auto_throttle_rules_response import GetAutoThrottleRulesResponse
from ._get_autonomous_notify_event_content_request import GetAutonomousNotifyEventContentRequest
from ._get_autonomous_notify_event_content_response_body import GetAutonomousNotifyEventContentResponseBody
from ._get_autonomous_notify_event_content_response import GetAutonomousNotifyEventContentResponse
from ._get_autonomous_notify_events_in_range_request import GetAutonomousNotifyEventsInRangeRequest
from ._get_autonomous_notify_events_in_range_response_body import GetAutonomousNotifyEventsInRangeResponseBody
from ._get_autonomous_notify_events_in_range_response import GetAutonomousNotifyEventsInRangeResponse
from ._get_blocking_detail_list_request import GetBlockingDetailListRequest
from ._get_blocking_detail_list_response_body import GetBlockingDetailListResponseBody
from ._get_blocking_detail_list_response import GetBlockingDetailListResponse
from ._get_dbinstance_connectivity_diagnosis_request import GetDBInstanceConnectivityDiagnosisRequest
from ._get_dbinstance_connectivity_diagnosis_response_body import GetDBInstanceConnectivityDiagnosisResponseBody
from ._get_dbinstance_connectivity_diagnosis_response import GetDBInstanceConnectivityDiagnosisResponse
from ._get_das_agent_sserequest import GetDasAgentSSERequest
from ._get_das_agent_sseresponse_body import GetDasAgentSSEResponseBody
from ._get_das_agent_sseresponse import GetDasAgentSSEResponse
from ._get_das_pro_service_usage_request import GetDasProServiceUsageRequest
from ._get_das_pro_service_usage_response_body import GetDasProServiceUsageResponseBody
from ._get_das_pro_service_usage_response import GetDasProServiceUsageResponse
from ._get_das_sqllog_hot_data_request import GetDasSQLLogHotDataRequest
from ._get_das_sqllog_hot_data_response_body import GetDasSQLLogHotDataResponseBody
from ._get_das_sqllog_hot_data_response import GetDasSQLLogHotDataResponse
from ._get_dead_lock_detail_request import GetDeadLockDetailRequest
from ._get_dead_lock_detail_response_body import GetDeadLockDetailResponseBody
from ._get_dead_lock_detail_response import GetDeadLockDetailResponse
from ._get_dead_lock_detail_list_request import GetDeadLockDetailListRequest
from ._get_dead_lock_detail_list_response_body import GetDeadLockDetailListResponseBody
from ._get_dead_lock_detail_list_response import GetDeadLockDetailListResponse
from ._get_dead_lock_history_request import GetDeadLockHistoryRequest
from ._get_dead_lock_history_response_body import GetDeadLockHistoryResponseBody
from ._get_dead_lock_history_response import GetDeadLockHistoryResponse
from ._get_deadlock_histogram_request import GetDeadlockHistogramRequest
from ._get_deadlock_histogram_response_body import GetDeadlockHistogramResponseBody
from ._get_deadlock_histogram_response import GetDeadlockHistogramResponse
from ._get_endpoint_switch_task_request import GetEndpointSwitchTaskRequest
from ._get_endpoint_switch_task_response_body import GetEndpointSwitchTaskResponseBody
from ._get_endpoint_switch_task_response import GetEndpointSwitchTaskResponse
from ._get_error_request_sample_request import GetErrorRequestSampleRequest
from ._get_error_request_sample_response_body import GetErrorRequestSampleResponseBody
from ._get_error_request_sample_response import GetErrorRequestSampleResponse
from ._get_event_subscription_request import GetEventSubscriptionRequest
from ._get_event_subscription_response_body import GetEventSubscriptionResponseBody
from ._get_event_subscription_response import GetEventSubscriptionResponse
from ._get_full_request_origin_stat_by_instance_id_request import GetFullRequestOriginStatByInstanceIdRequest
from ._get_full_request_origin_stat_by_instance_id_response_body import GetFullRequestOriginStatByInstanceIdResponseBody
from ._get_full_request_origin_stat_by_instance_id_response import GetFullRequestOriginStatByInstanceIdResponse
from ._get_full_request_sample_by_instance_id_request import GetFullRequestSampleByInstanceIdRequest
from ._get_full_request_sample_by_instance_id_response_body import GetFullRequestSampleByInstanceIdResponseBody
from ._get_full_request_sample_by_instance_id_response import GetFullRequestSampleByInstanceIdResponse
from ._get_full_request_stat_result_by_instance_id_request import GetFullRequestStatResultByInstanceIdRequest
from ._get_full_request_stat_result_by_instance_id_response_body import GetFullRequestStatResultByInstanceIdResponseBody
from ._get_full_request_stat_result_by_instance_id_response import GetFullRequestStatResultByInstanceIdResponse
from ._get_hdmaliyun_resource_sync_result_request import GetHDMAliyunResourceSyncResultRequest
from ._get_hdmaliyun_resource_sync_result_response_body import GetHDMAliyunResourceSyncResultResponseBody
from ._get_hdmaliyun_resource_sync_result_response import GetHDMAliyunResourceSyncResultResponse
from ._get_hdmlast_aliyun_resource_sync_result_request import GetHDMLastAliyunResourceSyncResultRequest
from ._get_hdmlast_aliyun_resource_sync_result_response_body import GetHDMLastAliyunResourceSyncResultResponseBody
from ._get_hdmlast_aliyun_resource_sync_result_response import GetHDMLastAliyunResourceSyncResultResponse
from ._get_instance_group_inspect_report_detail_request import GetInstanceGroupInspectReportDetailRequest
from ._get_instance_group_inspect_report_detail_response_body import GetInstanceGroupInspectReportDetailResponseBody
from ._get_instance_group_inspect_report_detail_response import GetInstanceGroupInspectReportDetailResponse
from ._get_instance_group_inspect_report_list_request import GetInstanceGroupInspectReportListRequest
from ._get_instance_group_inspect_report_list_response_body import GetInstanceGroupInspectReportListResponseBody
from ._get_instance_group_inspect_report_list_response import GetInstanceGroupInspectReportListResponse
from ._get_instance_inspections_request import GetInstanceInspectionsRequest
from ._get_instance_inspections_response_body import GetInstanceInspectionsResponseBody
from ._get_instance_inspections_response import GetInstanceInspectionsResponse
from ._get_instance_missing_index_list_request import GetInstanceMissingIndexListRequest
from ._get_instance_missing_index_list_response_body import GetInstanceMissingIndexListResponseBody
from ._get_instance_missing_index_list_response import GetInstanceMissingIndexListResponse
from ._get_instance_sql_optimize_statistic_request import GetInstanceSqlOptimizeStatisticRequest
from ._get_instance_sql_optimize_statistic_response_body import GetInstanceSqlOptimizeStatisticResponseBody
from ._get_instance_sql_optimize_statistic_response import GetInstanceSqlOptimizeStatisticResponse
from ._get_kill_instance_session_task_result_request import GetKillInstanceSessionTaskResultRequest
from ._get_kill_instance_session_task_result_response_body import GetKillInstanceSessionTaskResultResponseBody
from ._get_kill_instance_session_task_result_response import GetKillInstanceSessionTaskResultResponse
from ._get_mongo_dbcurrent_op_request import GetMongoDBCurrentOpRequest
from ._get_mongo_dbcurrent_op_response_body import GetMongoDBCurrentOpResponseBody
from ._get_mongo_dbcurrent_op_response import GetMongoDBCurrentOpResponse
from ._get_my_sqlall_session_async_request import GetMySQLAllSessionAsyncRequest
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBody
from ._get_my_sqlall_session_async_response import GetMySQLAllSessionAsyncResponse
from ._get_partitions_heatmap_request import GetPartitionsHeatmapRequest
from ._get_partitions_heatmap_response_body import GetPartitionsHeatmapResponseBody
from ._get_partitions_heatmap_response import GetPartitionsHeatmapResponse
from ._get_pfs_metric_trends_request import GetPfsMetricTrendsRequest
from ._get_pfs_metric_trends_response_body import GetPfsMetricTrendsResponseBody
from ._get_pfs_metric_trends_response import GetPfsMetricTrendsResponse
from ._get_pfs_sql_sample_request import GetPfsSqlSampleRequest
from ._get_pfs_sql_sample_response_body import GetPfsSqlSampleResponseBody
from ._get_pfs_sql_sample_response import GetPfsSqlSampleResponse
from ._get_pfs_sql_summaries_request import GetPfsSqlSummariesRequest
from ._get_pfs_sql_summaries_response_body import GetPfsSqlSummariesResponseBody
from ._get_pfs_sql_summaries_response import GetPfsSqlSummariesResponse
from ._get_query_optimize_data_stats_request import GetQueryOptimizeDataStatsRequest
from ._get_query_optimize_data_stats_response_body import GetQueryOptimizeDataStatsResponseBody
from ._get_query_optimize_data_stats_response import GetQueryOptimizeDataStatsResponse
from ._get_query_optimize_data_top_request import GetQueryOptimizeDataTopRequest
from ._get_query_optimize_data_top_response_body import GetQueryOptimizeDataTopResponseBody
from ._get_query_optimize_data_top_response import GetQueryOptimizeDataTopResponse
from ._get_query_optimize_data_trend_request import GetQueryOptimizeDataTrendRequest
from ._get_query_optimize_data_trend_response_body import GetQueryOptimizeDataTrendResponseBody
from ._get_query_optimize_data_trend_response import GetQueryOptimizeDataTrendResponse
from ._get_query_optimize_exec_error_sample_request import GetQueryOptimizeExecErrorSampleRequest
from ._get_query_optimize_exec_error_sample_response_body import GetQueryOptimizeExecErrorSampleResponseBody
from ._get_query_optimize_exec_error_sample_response import GetQueryOptimizeExecErrorSampleResponse
from ._get_query_optimize_exec_error_stats_request import GetQueryOptimizeExecErrorStatsRequest
from ._get_query_optimize_exec_error_stats_response_body import GetQueryOptimizeExecErrorStatsResponseBody
from ._get_query_optimize_exec_error_stats_response import GetQueryOptimizeExecErrorStatsResponse
from ._get_query_optimize_rule_list_request import GetQueryOptimizeRuleListRequest
from ._get_query_optimize_rule_list_response_body import GetQueryOptimizeRuleListResponseBody
from ._get_query_optimize_rule_list_response import GetQueryOptimizeRuleListResponse
from ._get_query_optimize_share_url_request import GetQueryOptimizeShareUrlRequest
from ._get_query_optimize_share_url_response_body import GetQueryOptimizeShareUrlResponseBody
from ._get_query_optimize_share_url_response import GetQueryOptimizeShareUrlResponse
from ._get_query_optimize_solution_request import GetQueryOptimizeSolutionRequest
from ._get_query_optimize_solution_response_body import GetQueryOptimizeSolutionResponseBody
from ._get_query_optimize_solution_response import GetQueryOptimizeSolutionResponse
from ._get_query_optimize_tag_request import GetQueryOptimizeTagRequest
from ._get_query_optimize_tag_response_body import GetQueryOptimizeTagResponseBody
from ._get_query_optimize_tag_response import GetQueryOptimizeTagResponse
from ._get_redis_all_session_request import GetRedisAllSessionRequest
from ._get_redis_all_session_response_body import GetRedisAllSessionResponseBody
from ._get_redis_all_session_response import GetRedisAllSessionResponse
from ._get_request_diagnosis_page_request import GetRequestDiagnosisPageRequest
from ._get_request_diagnosis_page_response_body import GetRequestDiagnosisPageResponseBody
from ._get_request_diagnosis_page_response import GetRequestDiagnosisPageResponse
from ._get_request_diagnosis_result_request import GetRequestDiagnosisResultRequest
from ._get_request_diagnosis_result_response_body import GetRequestDiagnosisResultResponseBody
from ._get_request_diagnosis_result_response import GetRequestDiagnosisResultResponse
from ._get_running_sql_concurrency_control_rules_request import GetRunningSqlConcurrencyControlRulesRequest
from ._get_running_sql_concurrency_control_rules_response_body import GetRunningSqlConcurrencyControlRulesResponseBody
from ._get_running_sql_concurrency_control_rules_response import GetRunningSqlConcurrencyControlRulesResponse
from ._get_sql_concurrency_control_keywords_from_sql_text_request import GetSqlConcurrencyControlKeywordsFromSqlTextRequest
from ._get_sql_concurrency_control_keywords_from_sql_text_response_body import GetSqlConcurrencyControlKeywordsFromSqlTextResponseBody
from ._get_sql_concurrency_control_keywords_from_sql_text_response import GetSqlConcurrencyControlKeywordsFromSqlTextResponse
from ._get_sql_concurrency_control_rules_history_request import GetSqlConcurrencyControlRulesHistoryRequest
from ._get_sql_concurrency_control_rules_history_response_body import GetSqlConcurrencyControlRulesHistoryResponseBody
from ._get_sql_concurrency_control_rules_history_response import GetSqlConcurrencyControlRulesHistoryResponse
from ._get_sql_optimize_advice_request import GetSqlOptimizeAdviceRequest
from ._get_sql_optimize_advice_response_body import GetSqlOptimizeAdviceResponseBody
from ._get_sql_optimize_advice_response import GetSqlOptimizeAdviceResponse
from ._get_storage_analysis_result_request import GetStorageAnalysisResultRequest
from ._get_storage_analysis_result_response_body import GetStorageAnalysisResultResponseBody
from ._get_storage_analysis_result_response import GetStorageAnalysisResultResponse
from ._get_yao_chi_agent_request import GetYaoChiAgentRequest
from ._get_yao_chi_agent_response_body import GetYaoChiAgentResponseBody
from ._get_yao_chi_agent_response import GetYaoChiAgentResponse
from ._kill_instance_all_session_request import KillInstanceAllSessionRequest
from ._kill_instance_all_session_response_body import KillInstanceAllSessionResponseBody
from ._kill_instance_all_session_response import KillInstanceAllSessionResponse
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequest
from ._modify_auto_scaling_config_response_body import ModifyAutoScalingConfigResponseBody
from ._modify_auto_scaling_config_response import ModifyAutoScalingConfigResponse
from ._modify_security_ipgroup_request import ModifySecurityIPGroupRequest
from ._modify_security_ipgroup_response_body import ModifySecurityIPGroupResponseBody
from ._modify_security_ipgroup_response import ModifySecurityIPGroupResponse
from ._modify_security_ipgroup_relation_request import ModifySecurityIPGroupRelationRequest
from ._modify_security_ipgroup_relation_response_body import ModifySecurityIPGroupRelationResponseBody
from ._modify_security_ipgroup_relation_response import ModifySecurityIPGroupRelationResponse
from ._modify_sql_log_config_request import ModifySqlLogConfigRequest
from ._modify_sql_log_config_response_body import ModifySqlLogConfigResponseBody
from ._modify_sql_log_config_response import ModifySqlLogConfigResponse
from ._run_cloud_bench_task_request import RunCloudBenchTaskRequest
from ._run_cloud_bench_task_response_body import RunCloudBenchTaskResponseBody
from ._run_cloud_bench_task_response import RunCloudBenchTaskResponse
from ._set_event_subscription_request import SetEventSubscriptionRequest
from ._set_event_subscription_response_body import SetEventSubscriptionResponseBody
from ._set_event_subscription_response import SetEventSubscriptionResponse
from ._update_auto_resource_optimize_rules_async_request import UpdateAutoResourceOptimizeRulesAsyncRequest
from ._update_auto_resource_optimize_rules_async_response_body import UpdateAutoResourceOptimizeRulesAsyncResponseBody
from ._update_auto_resource_optimize_rules_async_response import UpdateAutoResourceOptimizeRulesAsyncResponse
from ._update_auto_sql_optimize_status_request import UpdateAutoSqlOptimizeStatusRequest
from ._update_auto_sql_optimize_status_response_body import UpdateAutoSqlOptimizeStatusResponseBody
from ._update_auto_sql_optimize_status_response import UpdateAutoSqlOptimizeStatusResponse
from ._update_auto_throttle_rules_async_request import UpdateAutoThrottleRulesAsyncRequest
from ._update_auto_throttle_rules_async_response_body import UpdateAutoThrottleRulesAsyncResponseBody
from ._update_auto_throttle_rules_async_response import UpdateAutoThrottleRulesAsyncResponse
from ._add_hdminstance_response_body import AddHDMInstanceResponseBodyData
from ._create_cache_analysis_job_response_body import CreateCacheAnalysisJobResponseBodyDataBigKeysKeyInfo
from ._create_cache_analysis_job_response_body import CreateCacheAnalysisJobResponseBodyDataBigKeys
from ._create_cache_analysis_job_response_body import CreateCacheAnalysisJobResponseBodyData
from ._create_cloud_bench_tasks_response_body import CreateCloudBenchTasksResponseBodyData
from ._create_security_ipgroup_response_body import CreateSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup
from ._create_security_ipgroup_response_body import CreateSecurityIPGroupResponseBodyData
from ._create_sql_log_task_request import CreateSqlLogTaskRequestFilters
from ._create_sql_log_task_response_body import CreateSqlLogTaskResponseBodyData
from ._create_storage_analysis_task_response_body import CreateStorageAnalysisTaskResponseBodyData
from ._delete_security_ipgroup_response_body import DeleteSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup
from ._delete_security_ipgroup_response_body import DeleteSecurityIPGroupResponseBodyData
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyDataBandwidth
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyDataResource
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyDataShard
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyDataSpec
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyDataStorage
from ._describe_auto_scaling_config_response_body import DescribeAutoScalingConfigResponseBodyData
from ._describe_auto_scaling_history_response_body import DescribeAutoScalingHistoryResponseBodyDataSpecHistory
from ._describe_auto_scaling_history_response_body import DescribeAutoScalingHistoryResponseBodyData
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataBigKeysKeyInfo
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataBigKeys
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNumKeyInfo
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNum
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCountExpiryLevel
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCount
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataKeyPrefixesPrefix
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataKeyPrefixes
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytesKeyInfo
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytes
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNumKeyInfo
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNum
from ._describe_cache_analysis_job_response_body import DescribeCacheAnalysisJobResponseBodyData
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJobBigKeysKeyInfo
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJobBigKeys
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJob
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBodyDataList
from ._describe_cache_analysis_jobs_response_body import DescribeCacheAnalysisJobsResponseBodyData
from ._describe_cloud_bench_tasks_response_body import DescribeCloudBenchTasksResponseBodyDataListCloudbenchTasks
from ._describe_cloud_bench_tasks_response_body import DescribeCloudBenchTasksResponseBodyDataList
from ._describe_cloud_bench_tasks_response_body import DescribeCloudBenchTasksResponseBodyData
from ._describe_cloudbench_task_response_body import DescribeCloudbenchTaskResponseBodyData
from ._describe_cloudbench_task_config_response_body import DescribeCloudbenchTaskConfigResponseBodyData
from ._describe_error_log_records_request import DescribeErrorLogRecordsRequestFilters
from ._describe_error_log_records_response_body import DescribeErrorLogRecordsResponseBodyDataLogs
from ._describe_error_log_records_response_body import DescribeErrorLogRecordsResponseBodyData
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataBigKeysBigKey
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataBigKeys
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataHighTrafficKeysHighTrafficKey
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataHighTrafficKeys
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataHotKeysHotKey
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataHotKeys
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataLargeKeysLargeKey
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyDataLargeKeys
from ._describe_hot_big_keys_response_body import DescribeHotBigKeysResponseBodyData
from ._describe_hot_keys_response_body import DescribeHotKeysResponseBodyDataHotKey
from ._describe_hot_keys_response_body import DescribeHotKeysResponseBodyData
from ._describe_query_explain_response_body import DescribeQueryExplainResponseBodyData
from ._describe_security_ipgroup_response_body import DescribeSecurityIPGroupResponseBodyDataSecurityIpGroupsEngineInfoList
from ._describe_security_ipgroup_response_body import DescribeSecurityIPGroupResponseBodyDataSecurityIpGroups
from ._describe_security_ipgroup_response_body import DescribeSecurityIPGroupResponseBodyData
from ._describe_security_ipgroup_relation_response_body import DescribeSecurityIPGroupRelationResponseBodyDataGlobalSecurityIPGroupRel
from ._describe_security_ipgroup_relation_response_body import DescribeSecurityIPGroupRelationResponseBodyData
from ._describe_slow_log_histogram_async_request import DescribeSlowLogHistogramAsyncRequestFilters
from ._describe_slow_log_histogram_async_response_body import DescribeSlowLogHistogramAsyncResponseBodyDataDataItemInsItems
from ._describe_slow_log_histogram_async_response_body import DescribeSlowLogHistogramAsyncResponseBodyDataDataItem
from ._describe_slow_log_histogram_async_response_body import DescribeSlowLogHistogramAsyncResponseBodyDataData
from ._describe_slow_log_histogram_async_response_body import DescribeSlowLogHistogramAsyncResponseBodyData
from ._describe_slow_log_records_request import DescribeSlowLogRecordsRequestFilters
from ._describe_slow_log_records_response_body import DescribeSlowLogRecordsResponseBodyDataLogsSqlTag
from ._describe_slow_log_records_response_body import DescribeSlowLogRecordsResponseBodyDataLogs
from ._describe_slow_log_records_response_body import DescribeSlowLogRecordsResponseBodyData
from ._describe_slow_log_statistic_request import DescribeSlowLogStatisticRequestFilters
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataDataLogsHistogramItem
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataDataLogsHistogram
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataDataLogsSqlTag
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataDataLogsTrend
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataDataLogs
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyDataData
from ._describe_slow_log_statistic_response_body import DescribeSlowLogStatisticResponseBodyData
from ._describe_sql_log_config_response_body import DescribeSqlLogConfigResponseBodyData
from ._describe_sql_log_records_request import DescribeSqlLogRecordsRequestFilters
from ._describe_sql_log_records_response_body import DescribeSqlLogRecordsResponseBodyDataItemsSQLLogRecord
from ._describe_sql_log_records_response_body import DescribeSqlLogRecordsResponseBodyDataItems
from ._describe_sql_log_records_response_body import DescribeSqlLogRecordsResponseBodyData
from ._describe_sql_log_statistic_response_body import DescribeSqlLogStatisticResponseBodyData
from ._describe_sql_log_task_response_body import DescribeSqlLogTaskResponseBodyDataFilters
from ._describe_sql_log_task_response_body import DescribeSqlLogTaskResponseBodyDataQueries
from ._describe_sql_log_task_response_body import DescribeSqlLogTaskResponseBodyData
from ._describe_sql_log_tasks_request import DescribeSqlLogTasksRequestFilters
from ._describe_sql_log_tasks_response_body import DescribeSqlLogTasksResponseBodyDataListFilters
from ._describe_sql_log_tasks_response_body import DescribeSqlLogTasksResponseBodyDataList
from ._describe_sql_log_tasks_response_body import DescribeSqlLogTasksResponseBodyData
from ._describe_top_big_keys_response_body import DescribeTopBigKeysResponseBodyDataBigKey
from ._describe_top_big_keys_response_body import DescribeTopBigKeysResponseBodyData
from ._describe_top_hot_keys_response_body import DescribeTopHotKeysResponseBodyDataHotKey
from ._describe_top_hot_keys_response_body import DescribeTopHotKeysResponseBodyData
from ._disable_auto_resource_optimize_rules_response_body import DisableAutoResourceOptimizeRulesResponseBodyDataConfigFailInstanceList
from ._disable_auto_resource_optimize_rules_response_body import DisableAutoResourceOptimizeRulesResponseBodyDataConfigSuccessInstanceList
from ._disable_auto_resource_optimize_rules_response_body import DisableAutoResourceOptimizeRulesResponseBodyData
from ._disable_auto_throttle_rules_response_body import DisableAutoThrottleRulesResponseBodyDataConfigFailInstanceList
from ._disable_auto_throttle_rules_response_body import DisableAutoThrottleRulesResponseBodyDataConfigSuccessInstanceList
from ._disable_auto_throttle_rules_response_body import DisableAutoThrottleRulesResponseBodyData
from ._get_async_error_request_list_by_code_response_body import GetAsyncErrorRequestListByCodeResponseBodyDataResult
from ._get_async_error_request_list_by_code_response_body import GetAsyncErrorRequestListByCodeResponseBodyData
from ._get_async_error_request_stat_by_code_response_body import GetAsyncErrorRequestStatByCodeResponseBodyDataResult
from ._get_async_error_request_stat_by_code_response_body import GetAsyncErrorRequestStatByCodeResponseBodyData
from ._get_async_error_request_stat_result_response_body import GetAsyncErrorRequestStatResultResponseBodyData
from ._get_auto_increment_usage_statistic_response_body import GetAutoIncrementUsageStatisticResponseBodyDataAutoIncrementUsageList
from ._get_auto_increment_usage_statistic_response_body import GetAutoIncrementUsageStatisticResponseBodyData
from ._get_auto_resource_optimize_rules_response_body import GetAutoResourceOptimizeRulesResponseBodyDataEnableAutoResourceOptimizeList
from ._get_auto_resource_optimize_rules_response_body import GetAutoResourceOptimizeRulesResponseBodyDataHasEnableRuleButNotDasProList
from ._get_auto_resource_optimize_rules_response_body import GetAutoResourceOptimizeRulesResponseBodyDataTurnOffAutoResourceOptimizeList
from ._get_auto_resource_optimize_rules_response_body import GetAutoResourceOptimizeRulesResponseBodyData
from ._get_auto_throttle_rules_response_body import GetAutoThrottleRulesResponseBodyDataEnableAutoThrottleList
from ._get_auto_throttle_rules_response_body import GetAutoThrottleRulesResponseBodyDataTurnOffAutoThrottleList
from ._get_auto_throttle_rules_response_body import GetAutoThrottleRulesResponseBodyData
from ._get_autonomous_notify_events_in_range_response_body import GetAutonomousNotifyEventsInRangeResponseBodyDataList
from ._get_autonomous_notify_events_in_range_response_body import GetAutonomousNotifyEventsInRangeResponseBodyData
from ._get_blocking_detail_list_response_body import GetBlockingDetailListResponseBodyDataList
from ._get_blocking_detail_list_response_body import GetBlockingDetailListResponseBodyData
from ._get_dbinstance_connectivity_diagnosis_response_body import GetDBInstanceConnectivityDiagnosisResponseBodyData
from ._get_das_agent_sseresponse_body import GetDasAgentSSEResponseBodyMetadata
from ._get_das_pro_service_usage_response_body import GetDasProServiceUsageResponseBodyData
from ._get_das_sqllog_hot_data_response_body import GetDasSQLLogHotDataResponseBodyDataList
from ._get_das_sqllog_hot_data_response_body import GetDasSQLLogHotDataResponseBodyData
from ._get_dead_lock_detail_list_response_body import GetDeadLockDetailListResponseBodyDataListBlockProcessList
from ._get_dead_lock_detail_list_response_body import GetDeadLockDetailListResponseBodyDataList
from ._get_dead_lock_detail_list_response_body import GetDeadLockDetailListResponseBodyData
from ._get_deadlock_histogram_response_body import GetDeadlockHistogramResponseBodyData
from ._get_endpoint_switch_task_response_body import GetEndpointSwitchTaskResponseBodyData
from ._get_error_request_sample_response_body import GetErrorRequestSampleResponseBodyData
from ._get_event_subscription_response_body import GetEventSubscriptionResponseBodyDataContactGroups
from ._get_event_subscription_response_body import GetEventSubscriptionResponseBodyDataContacts
from ._get_event_subscription_response_body import GetEventSubscriptionResponseBodyData
from ._get_full_request_origin_stat_by_instance_id_response_body import GetFullRequestOriginStatByInstanceIdResponseBodyDataList
from ._get_full_request_origin_stat_by_instance_id_response_body import GetFullRequestOriginStatByInstanceIdResponseBodyData
from ._get_full_request_sample_by_instance_id_response_body import GetFullRequestSampleByInstanceIdResponseBodyData
from ._get_full_request_stat_result_by_instance_id_response_body import GetFullRequestStatResultByInstanceIdResponseBodyDataResultList
from ._get_full_request_stat_result_by_instance_id_response_body import GetFullRequestStatResultByInstanceIdResponseBodyDataResult
from ._get_full_request_stat_result_by_instance_id_response_body import GetFullRequestStatResultByInstanceIdResponseBodyData
from ._get_hdmaliyun_resource_sync_result_response_body import GetHDMAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult
from ._get_hdmaliyun_resource_sync_result_response_body import GetHDMAliyunResourceSyncResultResponseBodyDataSubResults
from ._get_hdmaliyun_resource_sync_result_response_body import GetHDMAliyunResourceSyncResultResponseBodyData
from ._get_hdmlast_aliyun_resource_sync_result_response_body import GetHDMLastAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult
from ._get_hdmlast_aliyun_resource_sync_result_response_body import GetHDMLastAliyunResourceSyncResultResponseBodyDataSubResults
from ._get_hdmlast_aliyun_resource_sync_result_response_body import GetHDMLastAliyunResourceSyncResultResponseBodyData
from ._get_instance_group_inspect_report_detail_response_body import GetInstanceGroupInspectReportDetailResponseBodyData
from ._get_instance_group_inspect_report_list_response_body import GetInstanceGroupInspectReportListResponseBodyData
from ._get_instance_inspections_response_body import GetInstanceInspectionsResponseBodyDataListAutoFunction
from ._get_instance_inspections_response_body import GetInstanceInspectionsResponseBodyDataListInstance
from ._get_instance_inspections_response_body import GetInstanceInspectionsResponseBodyDataList
from ._get_instance_inspections_response_body import GetInstanceInspectionsResponseBodyData
from ._get_instance_missing_index_list_response_body import GetInstanceMissingIndexListResponseBodyDataList
from ._get_instance_missing_index_list_response_body import GetInstanceMissingIndexListResponseBodyData
from ._get_instance_sql_optimize_statistic_response_body import GetInstanceSqlOptimizeStatisticResponseBodyData
from ._get_kill_instance_session_task_result_response_body import GetKillInstanceSessionTaskResultResponseBodyDataResult
from ._get_kill_instance_session_task_result_response_body import GetKillInstanceSessionTaskResultResponseBodyData
from ._get_mongo_dbcurrent_op_response_body import GetMongoDBCurrentOpResponseBodyDataSessionList
from ._get_mongo_dbcurrent_op_response_body import GetMongoDBCurrentOpResponseBodyDataSessionStat
from ._get_mongo_dbcurrent_op_response_body import GetMongoDBCurrentOpResponseBodyData
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyDataSessionDataClientStats
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyDataSessionDataDbStats
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyDataSessionDataSessionList
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyDataSessionDataUserStats
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyDataSessionData
from ._get_my_sqlall_session_async_response_body import GetMySQLAllSessionAsyncResponseBodyData
from ._get_pfs_sql_sample_response_body import GetPfsSqlSampleResponseBodyData
from ._get_pfs_sql_summaries_response_body import GetPfsSqlSummariesResponseBodyDataList
from ._get_pfs_sql_summaries_response_body import GetPfsSqlSummariesResponseBodyData
from ._get_query_optimize_data_stats_response_body import GetQueryOptimizeDataStatsResponseBodyDataListRuleList
from ._get_query_optimize_data_stats_response_body import GetQueryOptimizeDataStatsResponseBodyDataList
from ._get_query_optimize_data_stats_response_body import GetQueryOptimizeDataStatsResponseBodyData
from ._get_query_optimize_data_top_response_body import GetQueryOptimizeDataTopResponseBodyDataList
from ._get_query_optimize_data_top_response_body import GetQueryOptimizeDataTopResponseBodyData
from ._get_query_optimize_data_trend_response_body import GetQueryOptimizeDataTrendResponseBodyDataList
from ._get_query_optimize_data_trend_response_body import GetQueryOptimizeDataTrendResponseBodyData
from ._get_query_optimize_exec_error_sample_response_body import GetQueryOptimizeExecErrorSampleResponseBodyDataList
from ._get_query_optimize_exec_error_sample_response_body import GetQueryOptimizeExecErrorSampleResponseBodyData
from ._get_query_optimize_exec_error_stats_response_body import GetQueryOptimizeExecErrorStatsResponseBodyDataList
from ._get_query_optimize_exec_error_stats_response_body import GetQueryOptimizeExecErrorStatsResponseBodyData
from ._get_query_optimize_rule_list_response_body import GetQueryOptimizeRuleListResponseBodyDataList
from ._get_query_optimize_rule_list_response_body import GetQueryOptimizeRuleListResponseBodyData
from ._get_query_optimize_solution_response_body import GetQueryOptimizeSolutionResponseBodyDataList
from ._get_query_optimize_solution_response_body import GetQueryOptimizeSolutionResponseBodyData
from ._get_query_optimize_tag_response_body import GetQueryOptimizeTagResponseBodyData
from ._get_redis_all_session_response_body import GetRedisAllSessionResponseBodyDataSessions
from ._get_redis_all_session_response_body import GetRedisAllSessionResponseBodyDataSourceStats
from ._get_redis_all_session_response_body import GetRedisAllSessionResponseBodyData
from ._get_request_diagnosis_page_response_body import GetRequestDiagnosisPageResponseBodyDataList
from ._get_request_diagnosis_page_response_body import GetRequestDiagnosisPageResponseBodyData
from ._get_request_diagnosis_result_response_body import GetRequestDiagnosisResultResponseBodyData
from ._get_running_sql_concurrency_control_rules_response_body import GetRunningSqlConcurrencyControlRulesResponseBodyDataListRunningRules
from ._get_running_sql_concurrency_control_rules_response_body import GetRunningSqlConcurrencyControlRulesResponseBodyDataList
from ._get_running_sql_concurrency_control_rules_response_body import GetRunningSqlConcurrencyControlRulesResponseBodyData
from ._get_sql_concurrency_control_rules_history_response_body import GetSqlConcurrencyControlRulesHistoryResponseBodyDataListRules
from ._get_sql_concurrency_control_rules_history_response_body import GetSqlConcurrencyControlRulesHistoryResponseBodyDataList
from ._get_sql_concurrency_control_rules_history_response_body import GetSqlConcurrencyControlRulesHistoryResponseBodyData
from ._get_sql_optimize_advice_response_body import GetSqlOptimizeAdviceResponseBodyData
from ._get_storage_analysis_result_response_body import GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultNeedOptimizeItemList
from ._get_storage_analysis_result_response_body import GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultTableStats
from ._get_storage_analysis_result_response_body import GetStorageAnalysisResultResponseBodyDataStorageAnalysisResult
from ._get_storage_analysis_result_response_body import GetStorageAnalysisResultResponseBodyData
from ._get_yao_chi_agent_response_body import GetYaoChiAgentResponseBodyFunctionCall
from ._get_yao_chi_agent_response_body import GetYaoChiAgentResponseBodyUiFunctionCall
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequestBandwidth
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequestResource
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequestShard
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequestSpec
from ._modify_auto_scaling_config_request import ModifyAutoScalingConfigRequestStorage
from ._modify_security_ipgroup_response_body import ModifySecurityIPGroupResponseBodyDataGlobalSecurityIPGroup
from ._modify_security_ipgroup_response_body import ModifySecurityIPGroupResponseBodyData
from ._modify_security_ipgroup_relation_response_body import ModifySecurityIPGroupRelationResponseBodyDataGlobalSecurityIPGroupRel
from ._modify_security_ipgroup_relation_response_body import ModifySecurityIPGroupRelationResponseBodyData
from ._modify_sql_log_config_request import ModifySqlLogConfigRequestFilters
from ._modify_sql_log_config_response_body import ModifySqlLogConfigResponseBodyData
from ._run_cloud_bench_task_response_body import RunCloudBenchTaskResponseBodyDataPreCheckItem
from ._run_cloud_bench_task_response_body import RunCloudBenchTaskResponseBodyData
from ._set_event_subscription_response_body import SetEventSubscriptionResponseBodyData
from ._update_auto_resource_optimize_rules_async_response_body import UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponseConfigFailInstanceList
from ._update_auto_resource_optimize_rules_async_response_body import UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponseConfigSuccessInstanceList
from ._update_auto_resource_optimize_rules_async_response_body import UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponse
from ._update_auto_resource_optimize_rules_async_response_body import UpdateAutoResourceOptimizeRulesAsyncResponseBodyData
from ._update_auto_sql_optimize_status_response_body import UpdateAutoSqlOptimizeStatusResponseBodyData
from ._update_auto_throttle_rules_async_response_body import UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponseConfigFailInstanceList
from ._update_auto_throttle_rules_async_response_body import UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponseConfigSuccessInstanceList
from ._update_auto_throttle_rules_async_response_body import UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponse
from ._update_auto_throttle_rules_async_response_body import UpdateAutoThrottleRulesAsyncResponseBodyData

__all__ = [
    DataResultValue,
    DataSessionStatClientStatsValue,
    DataSessionStatDbStatsValue,
    DataValue,
    AddHDMInstanceRequest,
    AddHDMInstanceResponseBody,
    AddHDMInstanceResponse,
    CreateCacheAnalysisJobRequest,
    CreateCacheAnalysisJobResponseBody,
    CreateCacheAnalysisJobResponse,
    CreateCloudBenchTasksRequest,
    CreateCloudBenchTasksResponseBody,
    CreateCloudBenchTasksResponse,
    CreateDiagnosticReportRequest,
    CreateDiagnosticReportResponseBody,
    CreateDiagnosticReportResponse,
    CreateKillInstanceSessionTaskRequest,
    CreateKillInstanceSessionTaskResponseBody,
    CreateKillInstanceSessionTaskResponse,
    CreateKillInstanceSessionTaskWithMaintainUserRequest,
    CreateKillInstanceSessionTaskWithMaintainUserResponseBody,
    CreateKillInstanceSessionTaskWithMaintainUserResponse,
    CreateLatestDeadLockAnalysisRequest,
    CreateLatestDeadLockAnalysisResponseBody,
    CreateLatestDeadLockAnalysisResponse,
    CreateQueryOptimizeTagRequest,
    CreateQueryOptimizeTagResponseBody,
    CreateQueryOptimizeTagResponse,
    CreateRequestDiagnosisRequest,
    CreateRequestDiagnosisResponseBody,
    CreateRequestDiagnosisResponse,
    CreateSecurityIPGroupRequest,
    CreateSecurityIPGroupResponseBody,
    CreateSecurityIPGroupResponse,
    CreateSqlLogTaskRequest,
    CreateSqlLogTaskResponseBody,
    CreateSqlLogTaskResponse,
    CreateStorageAnalysisTaskRequest,
    CreateStorageAnalysisTaskResponseBody,
    CreateStorageAnalysisTaskResponse,
    DeleteCloudBenchTaskRequest,
    DeleteCloudBenchTaskResponseBody,
    DeleteCloudBenchTaskResponse,
    DeleteSecurityIPGroupRequest,
    DeleteSecurityIPGroupResponseBody,
    DeleteSecurityIPGroupResponse,
    DeleteStopGatewayRequest,
    DeleteStopGatewayResponseBody,
    DeleteStopGatewayResponse,
    DescribeAutoScalingConfigRequest,
    DescribeAutoScalingConfigResponseBody,
    DescribeAutoScalingConfigResponse,
    DescribeAutoScalingHistoryRequest,
    DescribeAutoScalingHistoryResponseBody,
    DescribeAutoScalingHistoryResponse,
    DescribeCacheAnalysisJobRequest,
    DescribeCacheAnalysisJobResponseBody,
    DescribeCacheAnalysisJobResponse,
    DescribeCacheAnalysisJobsRequest,
    DescribeCacheAnalysisJobsResponseBody,
    DescribeCacheAnalysisJobsResponse,
    DescribeCloudBenchTasksRequest,
    DescribeCloudBenchTasksResponseBody,
    DescribeCloudBenchTasksResponse,
    DescribeCloudbenchTaskRequest,
    DescribeCloudbenchTaskResponseBody,
    DescribeCloudbenchTaskResponse,
    DescribeCloudbenchTaskConfigRequest,
    DescribeCloudbenchTaskConfigResponseBody,
    DescribeCloudbenchTaskConfigResponse,
    DescribeDiagnosticReportListRequest,
    DescribeDiagnosticReportListResponseBody,
    DescribeDiagnosticReportListResponse,
    DescribeErrorLogRecordsRequest,
    DescribeErrorLogRecordsResponseBody,
    DescribeErrorLogRecordsResponse,
    DescribeHotBigKeysRequest,
    DescribeHotBigKeysResponseBody,
    DescribeHotBigKeysResponse,
    DescribeHotKeysRequest,
    DescribeHotKeysResponseBody,
    DescribeHotKeysResponse,
    DescribeInstanceDasProRequest,
    DescribeInstanceDasProResponseBody,
    DescribeInstanceDasProResponse,
    DescribeQueryExplainRequest,
    DescribeQueryExplainResponseBody,
    DescribeQueryExplainResponse,
    DescribeSecurityIPGroupRequest,
    DescribeSecurityIPGroupResponseBody,
    DescribeSecurityIPGroupResponse,
    DescribeSecurityIPGroupRelationRequest,
    DescribeSecurityIPGroupRelationResponseBody,
    DescribeSecurityIPGroupRelationResponse,
    DescribeSlowLogHistogramAsyncRequest,
    DescribeSlowLogHistogramAsyncResponseBody,
    DescribeSlowLogHistogramAsyncResponse,
    DescribeSlowLogRecordsRequest,
    DescribeSlowLogRecordsResponseBody,
    DescribeSlowLogRecordsResponse,
    DescribeSlowLogStatisticRequest,
    DescribeSlowLogStatisticResponseBody,
    DescribeSlowLogStatisticResponse,
    DescribeSqlLogConfigRequest,
    DescribeSqlLogConfigResponseBody,
    DescribeSqlLogConfigResponse,
    DescribeSqlLogRecordsRequest,
    DescribeSqlLogRecordsResponseBody,
    DescribeSqlLogRecordsResponse,
    DescribeSqlLogStatisticRequest,
    DescribeSqlLogStatisticResponseBody,
    DescribeSqlLogStatisticResponse,
    DescribeSqlLogTaskRequest,
    DescribeSqlLogTaskResponseBody,
    DescribeSqlLogTaskResponse,
    DescribeSqlLogTasksRequest,
    DescribeSqlLogTasksResponseBody,
    DescribeSqlLogTasksResponse,
    DescribeTopBigKeysRequest,
    DescribeTopBigKeysResponseBody,
    DescribeTopBigKeysResponse,
    DescribeTopHotKeysRequest,
    DescribeTopHotKeysResponseBody,
    DescribeTopHotKeysResponse,
    DisableAllSqlConcurrencyControlRulesRequest,
    DisableAllSqlConcurrencyControlRulesResponseBody,
    DisableAllSqlConcurrencyControlRulesResponse,
    DisableAutoResourceOptimizeRulesRequest,
    DisableAutoResourceOptimizeRulesResponseBody,
    DisableAutoResourceOptimizeRulesResponse,
    DisableAutoThrottleRulesRequest,
    DisableAutoThrottleRulesResponseBody,
    DisableAutoThrottleRulesResponse,
    DisableDasProRequest,
    DisableDasProResponseBody,
    DisableDasProResponse,
    DisableInstanceDasConfigRequest,
    DisableInstanceDasConfigResponseBody,
    DisableInstanceDasConfigResponse,
    DisableSqlConcurrencyControlRequest,
    DisableSqlConcurrencyControlResponseBody,
    DisableSqlConcurrencyControlResponse,
    EnableDasProRequest,
    EnableDasProResponseBody,
    EnableDasProResponse,
    EnableSqlConcurrencyControlRequest,
    EnableSqlConcurrencyControlResponseBody,
    EnableSqlConcurrencyControlResponse,
    GetAsyncErrorRequestListByCodeRequest,
    GetAsyncErrorRequestListByCodeResponseBody,
    GetAsyncErrorRequestListByCodeResponse,
    GetAsyncErrorRequestStatByCodeRequest,
    GetAsyncErrorRequestStatByCodeResponseBody,
    GetAsyncErrorRequestStatByCodeResponse,
    GetAsyncErrorRequestStatResultRequest,
    GetAsyncErrorRequestStatResultResponseBody,
    GetAsyncErrorRequestStatResultResponse,
    GetAutoIncrementUsageStatisticRequest,
    GetAutoIncrementUsageStatisticResponseBody,
    GetAutoIncrementUsageStatisticResponse,
    GetAutoResourceOptimizeRulesRequest,
    GetAutoResourceOptimizeRulesResponseBody,
    GetAutoResourceOptimizeRulesResponse,
    GetAutoThrottleRulesRequest,
    GetAutoThrottleRulesResponseBody,
    GetAutoThrottleRulesResponse,
    GetAutonomousNotifyEventContentRequest,
    GetAutonomousNotifyEventContentResponseBody,
    GetAutonomousNotifyEventContentResponse,
    GetAutonomousNotifyEventsInRangeRequest,
    GetAutonomousNotifyEventsInRangeResponseBody,
    GetAutonomousNotifyEventsInRangeResponse,
    GetBlockingDetailListRequest,
    GetBlockingDetailListResponseBody,
    GetBlockingDetailListResponse,
    GetDBInstanceConnectivityDiagnosisRequest,
    GetDBInstanceConnectivityDiagnosisResponseBody,
    GetDBInstanceConnectivityDiagnosisResponse,
    GetDasAgentSSERequest,
    GetDasAgentSSEResponseBody,
    GetDasAgentSSEResponse,
    GetDasProServiceUsageRequest,
    GetDasProServiceUsageResponseBody,
    GetDasProServiceUsageResponse,
    GetDasSQLLogHotDataRequest,
    GetDasSQLLogHotDataResponseBody,
    GetDasSQLLogHotDataResponse,
    GetDeadLockDetailRequest,
    GetDeadLockDetailResponseBody,
    GetDeadLockDetailResponse,
    GetDeadLockDetailListRequest,
    GetDeadLockDetailListResponseBody,
    GetDeadLockDetailListResponse,
    GetDeadLockHistoryRequest,
    GetDeadLockHistoryResponseBody,
    GetDeadLockHistoryResponse,
    GetDeadlockHistogramRequest,
    GetDeadlockHistogramResponseBody,
    GetDeadlockHistogramResponse,
    GetEndpointSwitchTaskRequest,
    GetEndpointSwitchTaskResponseBody,
    GetEndpointSwitchTaskResponse,
    GetErrorRequestSampleRequest,
    GetErrorRequestSampleResponseBody,
    GetErrorRequestSampleResponse,
    GetEventSubscriptionRequest,
    GetEventSubscriptionResponseBody,
    GetEventSubscriptionResponse,
    GetFullRequestOriginStatByInstanceIdRequest,
    GetFullRequestOriginStatByInstanceIdResponseBody,
    GetFullRequestOriginStatByInstanceIdResponse,
    GetFullRequestSampleByInstanceIdRequest,
    GetFullRequestSampleByInstanceIdResponseBody,
    GetFullRequestSampleByInstanceIdResponse,
    GetFullRequestStatResultByInstanceIdRequest,
    GetFullRequestStatResultByInstanceIdResponseBody,
    GetFullRequestStatResultByInstanceIdResponse,
    GetHDMAliyunResourceSyncResultRequest,
    GetHDMAliyunResourceSyncResultResponseBody,
    GetHDMAliyunResourceSyncResultResponse,
    GetHDMLastAliyunResourceSyncResultRequest,
    GetHDMLastAliyunResourceSyncResultResponseBody,
    GetHDMLastAliyunResourceSyncResultResponse,
    GetInstanceGroupInspectReportDetailRequest,
    GetInstanceGroupInspectReportDetailResponseBody,
    GetInstanceGroupInspectReportDetailResponse,
    GetInstanceGroupInspectReportListRequest,
    GetInstanceGroupInspectReportListResponseBody,
    GetInstanceGroupInspectReportListResponse,
    GetInstanceInspectionsRequest,
    GetInstanceInspectionsResponseBody,
    GetInstanceInspectionsResponse,
    GetInstanceMissingIndexListRequest,
    GetInstanceMissingIndexListResponseBody,
    GetInstanceMissingIndexListResponse,
    GetInstanceSqlOptimizeStatisticRequest,
    GetInstanceSqlOptimizeStatisticResponseBody,
    GetInstanceSqlOptimizeStatisticResponse,
    GetKillInstanceSessionTaskResultRequest,
    GetKillInstanceSessionTaskResultResponseBody,
    GetKillInstanceSessionTaskResultResponse,
    GetMongoDBCurrentOpRequest,
    GetMongoDBCurrentOpResponseBody,
    GetMongoDBCurrentOpResponse,
    GetMySQLAllSessionAsyncRequest,
    GetMySQLAllSessionAsyncResponseBody,
    GetMySQLAllSessionAsyncResponse,
    GetPartitionsHeatmapRequest,
    GetPartitionsHeatmapResponseBody,
    GetPartitionsHeatmapResponse,
    GetPfsMetricTrendsRequest,
    GetPfsMetricTrendsResponseBody,
    GetPfsMetricTrendsResponse,
    GetPfsSqlSampleRequest,
    GetPfsSqlSampleResponseBody,
    GetPfsSqlSampleResponse,
    GetPfsSqlSummariesRequest,
    GetPfsSqlSummariesResponseBody,
    GetPfsSqlSummariesResponse,
    GetQueryOptimizeDataStatsRequest,
    GetQueryOptimizeDataStatsResponseBody,
    GetQueryOptimizeDataStatsResponse,
    GetQueryOptimizeDataTopRequest,
    GetQueryOptimizeDataTopResponseBody,
    GetQueryOptimizeDataTopResponse,
    GetQueryOptimizeDataTrendRequest,
    GetQueryOptimizeDataTrendResponseBody,
    GetQueryOptimizeDataTrendResponse,
    GetQueryOptimizeExecErrorSampleRequest,
    GetQueryOptimizeExecErrorSampleResponseBody,
    GetQueryOptimizeExecErrorSampleResponse,
    GetQueryOptimizeExecErrorStatsRequest,
    GetQueryOptimizeExecErrorStatsResponseBody,
    GetQueryOptimizeExecErrorStatsResponse,
    GetQueryOptimizeRuleListRequest,
    GetQueryOptimizeRuleListResponseBody,
    GetQueryOptimizeRuleListResponse,
    GetQueryOptimizeShareUrlRequest,
    GetQueryOptimizeShareUrlResponseBody,
    GetQueryOptimizeShareUrlResponse,
    GetQueryOptimizeSolutionRequest,
    GetQueryOptimizeSolutionResponseBody,
    GetQueryOptimizeSolutionResponse,
    GetQueryOptimizeTagRequest,
    GetQueryOptimizeTagResponseBody,
    GetQueryOptimizeTagResponse,
    GetRedisAllSessionRequest,
    GetRedisAllSessionResponseBody,
    GetRedisAllSessionResponse,
    GetRequestDiagnosisPageRequest,
    GetRequestDiagnosisPageResponseBody,
    GetRequestDiagnosisPageResponse,
    GetRequestDiagnosisResultRequest,
    GetRequestDiagnosisResultResponseBody,
    GetRequestDiagnosisResultResponse,
    GetRunningSqlConcurrencyControlRulesRequest,
    GetRunningSqlConcurrencyControlRulesResponseBody,
    GetRunningSqlConcurrencyControlRulesResponse,
    GetSqlConcurrencyControlKeywordsFromSqlTextRequest,
    GetSqlConcurrencyControlKeywordsFromSqlTextResponseBody,
    GetSqlConcurrencyControlKeywordsFromSqlTextResponse,
    GetSqlConcurrencyControlRulesHistoryRequest,
    GetSqlConcurrencyControlRulesHistoryResponseBody,
    GetSqlConcurrencyControlRulesHistoryResponse,
    GetSqlOptimizeAdviceRequest,
    GetSqlOptimizeAdviceResponseBody,
    GetSqlOptimizeAdviceResponse,
    GetStorageAnalysisResultRequest,
    GetStorageAnalysisResultResponseBody,
    GetStorageAnalysisResultResponse,
    GetYaoChiAgentRequest,
    GetYaoChiAgentResponseBody,
    GetYaoChiAgentResponse,
    KillInstanceAllSessionRequest,
    KillInstanceAllSessionResponseBody,
    KillInstanceAllSessionResponse,
    ModifyAutoScalingConfigRequest,
    ModifyAutoScalingConfigResponseBody,
    ModifyAutoScalingConfigResponse,
    ModifySecurityIPGroupRequest,
    ModifySecurityIPGroupResponseBody,
    ModifySecurityIPGroupResponse,
    ModifySecurityIPGroupRelationRequest,
    ModifySecurityIPGroupRelationResponseBody,
    ModifySecurityIPGroupRelationResponse,
    ModifySqlLogConfigRequest,
    ModifySqlLogConfigResponseBody,
    ModifySqlLogConfigResponse,
    RunCloudBenchTaskRequest,
    RunCloudBenchTaskResponseBody,
    RunCloudBenchTaskResponse,
    SetEventSubscriptionRequest,
    SetEventSubscriptionResponseBody,
    SetEventSubscriptionResponse,
    UpdateAutoResourceOptimizeRulesAsyncRequest,
    UpdateAutoResourceOptimizeRulesAsyncResponseBody,
    UpdateAutoResourceOptimizeRulesAsyncResponse,
    UpdateAutoSqlOptimizeStatusRequest,
    UpdateAutoSqlOptimizeStatusResponseBody,
    UpdateAutoSqlOptimizeStatusResponse,
    UpdateAutoThrottleRulesAsyncRequest,
    UpdateAutoThrottleRulesAsyncResponseBody,
    UpdateAutoThrottleRulesAsyncResponse,
    AddHDMInstanceResponseBodyData,
    CreateCacheAnalysisJobResponseBodyDataBigKeysKeyInfo,
    CreateCacheAnalysisJobResponseBodyDataBigKeys,
    CreateCacheAnalysisJobResponseBodyData,
    CreateCloudBenchTasksResponseBodyData,
    CreateSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup,
    CreateSecurityIPGroupResponseBodyData,
    CreateSqlLogTaskRequestFilters,
    CreateSqlLogTaskResponseBodyData,
    CreateStorageAnalysisTaskResponseBodyData,
    DeleteSecurityIPGroupResponseBodyDataGlobalSecurityIPGroup,
    DeleteSecurityIPGroupResponseBodyData,
    DescribeAutoScalingConfigResponseBodyDataBandwidth,
    DescribeAutoScalingConfigResponseBodyDataResource,
    DescribeAutoScalingConfigResponseBodyDataShard,
    DescribeAutoScalingConfigResponseBodyDataSpec,
    DescribeAutoScalingConfigResponseBodyDataStorage,
    DescribeAutoScalingConfigResponseBodyData,
    DescribeAutoScalingHistoryResponseBodyDataSpecHistory,
    DescribeAutoScalingHistoryResponseBodyData,
    DescribeCacheAnalysisJobResponseBodyDataBigKeysKeyInfo,
    DescribeCacheAnalysisJobResponseBodyDataBigKeys,
    DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNumKeyInfo,
    DescribeCacheAnalysisJobResponseBodyDataBigKeysOfNum,
    DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCountExpiryLevel,
    DescribeCacheAnalysisJobResponseBodyDataExpiryKeysLevelCount,
    DescribeCacheAnalysisJobResponseBodyDataKeyPrefixesPrefix,
    DescribeCacheAnalysisJobResponseBodyDataKeyPrefixes,
    DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytesKeyInfo,
    DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfBytes,
    DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNumKeyInfo,
    DescribeCacheAnalysisJobResponseBodyDataUnexBigKeysOfNum,
    DescribeCacheAnalysisJobResponseBodyData,
    DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJobBigKeysKeyInfo,
    DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJobBigKeys,
    DescribeCacheAnalysisJobsResponseBodyDataListCacheAnalysisJob,
    DescribeCacheAnalysisJobsResponseBodyDataList,
    DescribeCacheAnalysisJobsResponseBodyData,
    DescribeCloudBenchTasksResponseBodyDataListCloudbenchTasks,
    DescribeCloudBenchTasksResponseBodyDataList,
    DescribeCloudBenchTasksResponseBodyData,
    DescribeCloudbenchTaskResponseBodyData,
    DescribeCloudbenchTaskConfigResponseBodyData,
    DescribeErrorLogRecordsRequestFilters,
    DescribeErrorLogRecordsResponseBodyDataLogs,
    DescribeErrorLogRecordsResponseBodyData,
    DescribeHotBigKeysResponseBodyDataBigKeysBigKey,
    DescribeHotBigKeysResponseBodyDataBigKeys,
    DescribeHotBigKeysResponseBodyDataHighTrafficKeysHighTrafficKey,
    DescribeHotBigKeysResponseBodyDataHighTrafficKeys,
    DescribeHotBigKeysResponseBodyDataHotKeysHotKey,
    DescribeHotBigKeysResponseBodyDataHotKeys,
    DescribeHotBigKeysResponseBodyDataLargeKeysLargeKey,
    DescribeHotBigKeysResponseBodyDataLargeKeys,
    DescribeHotBigKeysResponseBodyData,
    DescribeHotKeysResponseBodyDataHotKey,
    DescribeHotKeysResponseBodyData,
    DescribeQueryExplainResponseBodyData,
    DescribeSecurityIPGroupResponseBodyDataSecurityIpGroupsEngineInfoList,
    DescribeSecurityIPGroupResponseBodyDataSecurityIpGroups,
    DescribeSecurityIPGroupResponseBodyData,
    DescribeSecurityIPGroupRelationResponseBodyDataGlobalSecurityIPGroupRel,
    DescribeSecurityIPGroupRelationResponseBodyData,
    DescribeSlowLogHistogramAsyncRequestFilters,
    DescribeSlowLogHistogramAsyncResponseBodyDataDataItemInsItems,
    DescribeSlowLogHistogramAsyncResponseBodyDataDataItem,
    DescribeSlowLogHistogramAsyncResponseBodyDataData,
    DescribeSlowLogHistogramAsyncResponseBodyData,
    DescribeSlowLogRecordsRequestFilters,
    DescribeSlowLogRecordsResponseBodyDataLogsSqlTag,
    DescribeSlowLogRecordsResponseBodyDataLogs,
    DescribeSlowLogRecordsResponseBodyData,
    DescribeSlowLogStatisticRequestFilters,
    DescribeSlowLogStatisticResponseBodyDataDataLogsHistogramItem,
    DescribeSlowLogStatisticResponseBodyDataDataLogsHistogram,
    DescribeSlowLogStatisticResponseBodyDataDataLogsSqlTag,
    DescribeSlowLogStatisticResponseBodyDataDataLogsTrend,
    DescribeSlowLogStatisticResponseBodyDataDataLogs,
    DescribeSlowLogStatisticResponseBodyDataData,
    DescribeSlowLogStatisticResponseBodyData,
    DescribeSqlLogConfigResponseBodyData,
    DescribeSqlLogRecordsRequestFilters,
    DescribeSqlLogRecordsResponseBodyDataItemsSQLLogRecord,
    DescribeSqlLogRecordsResponseBodyDataItems,
    DescribeSqlLogRecordsResponseBodyData,
    DescribeSqlLogStatisticResponseBodyData,
    DescribeSqlLogTaskResponseBodyDataFilters,
    DescribeSqlLogTaskResponseBodyDataQueries,
    DescribeSqlLogTaskResponseBodyData,
    DescribeSqlLogTasksRequestFilters,
    DescribeSqlLogTasksResponseBodyDataListFilters,
    DescribeSqlLogTasksResponseBodyDataList,
    DescribeSqlLogTasksResponseBodyData,
    DescribeTopBigKeysResponseBodyDataBigKey,
    DescribeTopBigKeysResponseBodyData,
    DescribeTopHotKeysResponseBodyDataHotKey,
    DescribeTopHotKeysResponseBodyData,
    DisableAutoResourceOptimizeRulesResponseBodyDataConfigFailInstanceList,
    DisableAutoResourceOptimizeRulesResponseBodyDataConfigSuccessInstanceList,
    DisableAutoResourceOptimizeRulesResponseBodyData,
    DisableAutoThrottleRulesResponseBodyDataConfigFailInstanceList,
    DisableAutoThrottleRulesResponseBodyDataConfigSuccessInstanceList,
    DisableAutoThrottleRulesResponseBodyData,
    GetAsyncErrorRequestListByCodeResponseBodyDataResult,
    GetAsyncErrorRequestListByCodeResponseBodyData,
    GetAsyncErrorRequestStatByCodeResponseBodyDataResult,
    GetAsyncErrorRequestStatByCodeResponseBodyData,
    GetAsyncErrorRequestStatResultResponseBodyData,
    GetAutoIncrementUsageStatisticResponseBodyDataAutoIncrementUsageList,
    GetAutoIncrementUsageStatisticResponseBodyData,
    GetAutoResourceOptimizeRulesResponseBodyDataEnableAutoResourceOptimizeList,
    GetAutoResourceOptimizeRulesResponseBodyDataHasEnableRuleButNotDasProList,
    GetAutoResourceOptimizeRulesResponseBodyDataTurnOffAutoResourceOptimizeList,
    GetAutoResourceOptimizeRulesResponseBodyData,
    GetAutoThrottleRulesResponseBodyDataEnableAutoThrottleList,
    GetAutoThrottleRulesResponseBodyDataTurnOffAutoThrottleList,
    GetAutoThrottleRulesResponseBodyData,
    GetAutonomousNotifyEventsInRangeResponseBodyDataList,
    GetAutonomousNotifyEventsInRangeResponseBodyData,
    GetBlockingDetailListResponseBodyDataList,
    GetBlockingDetailListResponseBodyData,
    GetDBInstanceConnectivityDiagnosisResponseBodyData,
    GetDasAgentSSEResponseBodyMetadata,
    GetDasProServiceUsageResponseBodyData,
    GetDasSQLLogHotDataResponseBodyDataList,
    GetDasSQLLogHotDataResponseBodyData,
    GetDeadLockDetailListResponseBodyDataListBlockProcessList,
    GetDeadLockDetailListResponseBodyDataList,
    GetDeadLockDetailListResponseBodyData,
    GetDeadlockHistogramResponseBodyData,
    GetEndpointSwitchTaskResponseBodyData,
    GetErrorRequestSampleResponseBodyData,
    GetEventSubscriptionResponseBodyDataContactGroups,
    GetEventSubscriptionResponseBodyDataContacts,
    GetEventSubscriptionResponseBodyData,
    GetFullRequestOriginStatByInstanceIdResponseBodyDataList,
    GetFullRequestOriginStatByInstanceIdResponseBodyData,
    GetFullRequestSampleByInstanceIdResponseBodyData,
    GetFullRequestStatResultByInstanceIdResponseBodyDataResultList,
    GetFullRequestStatResultByInstanceIdResponseBodyDataResult,
    GetFullRequestStatResultByInstanceIdResponseBodyData,
    GetHDMAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult,
    GetHDMAliyunResourceSyncResultResponseBodyDataSubResults,
    GetHDMAliyunResourceSyncResultResponseBodyData,
    GetHDMLastAliyunResourceSyncResultResponseBodyDataSubResultsResourceSyncSubResult,
    GetHDMLastAliyunResourceSyncResultResponseBodyDataSubResults,
    GetHDMLastAliyunResourceSyncResultResponseBodyData,
    GetInstanceGroupInspectReportDetailResponseBodyData,
    GetInstanceGroupInspectReportListResponseBodyData,
    GetInstanceInspectionsResponseBodyDataListAutoFunction,
    GetInstanceInspectionsResponseBodyDataListInstance,
    GetInstanceInspectionsResponseBodyDataList,
    GetInstanceInspectionsResponseBodyData,
    GetInstanceMissingIndexListResponseBodyDataList,
    GetInstanceMissingIndexListResponseBodyData,
    GetInstanceSqlOptimizeStatisticResponseBodyData,
    GetKillInstanceSessionTaskResultResponseBodyDataResult,
    GetKillInstanceSessionTaskResultResponseBodyData,
    GetMongoDBCurrentOpResponseBodyDataSessionList,
    GetMongoDBCurrentOpResponseBodyDataSessionStat,
    GetMongoDBCurrentOpResponseBodyData,
    GetMySQLAllSessionAsyncResponseBodyDataSessionDataClientStats,
    GetMySQLAllSessionAsyncResponseBodyDataSessionDataDbStats,
    GetMySQLAllSessionAsyncResponseBodyDataSessionDataSessionList,
    GetMySQLAllSessionAsyncResponseBodyDataSessionDataUserStats,
    GetMySQLAllSessionAsyncResponseBodyDataSessionData,
    GetMySQLAllSessionAsyncResponseBodyData,
    GetPfsSqlSampleResponseBodyData,
    GetPfsSqlSummariesResponseBodyDataList,
    GetPfsSqlSummariesResponseBodyData,
    GetQueryOptimizeDataStatsResponseBodyDataListRuleList,
    GetQueryOptimizeDataStatsResponseBodyDataList,
    GetQueryOptimizeDataStatsResponseBodyData,
    GetQueryOptimizeDataTopResponseBodyDataList,
    GetQueryOptimizeDataTopResponseBodyData,
    GetQueryOptimizeDataTrendResponseBodyDataList,
    GetQueryOptimizeDataTrendResponseBodyData,
    GetQueryOptimizeExecErrorSampleResponseBodyDataList,
    GetQueryOptimizeExecErrorSampleResponseBodyData,
    GetQueryOptimizeExecErrorStatsResponseBodyDataList,
    GetQueryOptimizeExecErrorStatsResponseBodyData,
    GetQueryOptimizeRuleListResponseBodyDataList,
    GetQueryOptimizeRuleListResponseBodyData,
    GetQueryOptimizeSolutionResponseBodyDataList,
    GetQueryOptimizeSolutionResponseBodyData,
    GetQueryOptimizeTagResponseBodyData,
    GetRedisAllSessionResponseBodyDataSessions,
    GetRedisAllSessionResponseBodyDataSourceStats,
    GetRedisAllSessionResponseBodyData,
    GetRequestDiagnosisPageResponseBodyDataList,
    GetRequestDiagnosisPageResponseBodyData,
    GetRequestDiagnosisResultResponseBodyData,
    GetRunningSqlConcurrencyControlRulesResponseBodyDataListRunningRules,
    GetRunningSqlConcurrencyControlRulesResponseBodyDataList,
    GetRunningSqlConcurrencyControlRulesResponseBodyData,
    GetSqlConcurrencyControlRulesHistoryResponseBodyDataListRules,
    GetSqlConcurrencyControlRulesHistoryResponseBodyDataList,
    GetSqlConcurrencyControlRulesHistoryResponseBodyData,
    GetSqlOptimizeAdviceResponseBodyData,
    GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultNeedOptimizeItemList,
    GetStorageAnalysisResultResponseBodyDataStorageAnalysisResultTableStats,
    GetStorageAnalysisResultResponseBodyDataStorageAnalysisResult,
    GetStorageAnalysisResultResponseBodyData,
    GetYaoChiAgentResponseBodyFunctionCall,
    GetYaoChiAgentResponseBodyUiFunctionCall,
    ModifyAutoScalingConfigRequestBandwidth,
    ModifyAutoScalingConfigRequestResource,
    ModifyAutoScalingConfigRequestShard,
    ModifyAutoScalingConfigRequestSpec,
    ModifyAutoScalingConfigRequestStorage,
    ModifySecurityIPGroupResponseBodyDataGlobalSecurityIPGroup,
    ModifySecurityIPGroupResponseBodyData,
    ModifySecurityIPGroupRelationResponseBodyDataGlobalSecurityIPGroupRel,
    ModifySecurityIPGroupRelationResponseBodyData,
    ModifySqlLogConfigRequestFilters,
    ModifySqlLogConfigResponseBodyData,
    RunCloudBenchTaskResponseBodyDataPreCheckItem,
    RunCloudBenchTaskResponseBodyData,
    SetEventSubscriptionResponseBodyData,
    UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponseConfigFailInstanceList,
    UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponseConfigSuccessInstanceList,
    UpdateAutoResourceOptimizeRulesAsyncResponseBodyDataConfigResponse,
    UpdateAutoResourceOptimizeRulesAsyncResponseBodyData,
    UpdateAutoSqlOptimizeStatusResponseBodyData,
    UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponseConfigFailInstanceList,
    UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponseConfigSuccessInstanceList,
    UpdateAutoThrottleRulesAsyncResponseBodyDataConfigResponse,
    UpdateAutoThrottleRulesAsyncResponseBodyData
]
